//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Application/GlobalSettings.h
//! @brief     Defines class Application
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_APPLICATION_GLOBALSETTINGS_H
#define BORNAGAIN_GUI_APPLICATION_GLOBALSETTINGS_H

#include "GUI/Application/ApplicationSettings.h"
#include <QColor>

//! Provides access to application wide stuff like settings.

class GlobalSettings {
public:
    GlobalSettings();

    ApplicationSettings& settings();

    void loadStyle(ApplicationSettings::Style style);
    ApplicationSettings::Style currentStyle();

    struct Palette {
        QColor headlineText;
        QColor headlineBackground;
    };

    const Palette& styleSheetPalette() const;

    //! The folder where persistent application data shall be stored. E.g. in Windows this is the
    //! AppData/Roaming location.
    //! Used e.g. for storing the instrument library.
    QString appDataFolder() const;

private:
    ApplicationSettings m_settings;
    ApplicationSettings::Style m_currentStyle;
    Palette m_styleSheetPalette;
};

extern GlobalSettings* baApp; //!< global pointer to the single instance

#endif // BORNAGAIN_GUI_APPLICATION_GLOBALSETTINGS_H
